@@ -4,14 +4,14 @@ use strict 'subs', 'vars';
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-02'; # DATE
+our $DATE = '2023-11-30'; # DATE
 our $DIST = 'App-FileTestUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Getopt::Long qw(:config auto_help auto_version gnu_getopt no_ignore_case);
 
 sub do_script {
-    require File::MoreUtil;
+    require File::Util::Test;
     my ($func) = @_;
 
     (my $script = $func) =~ s/_/-/g;
@@ -27,14 +27,14 @@ sub do_script {
         my @files = @ARGV;
         unless (@files) { chomp(@files = <STDIN>) }
         for my $file (@files) {
-            if (&{"File::MoreUtil::$func"}($file) xor $opt_invert_match) { print $file, "\n" }
+            if (&{"File::Util::Test::$func"}($file) xor $opt_invert_match) { print $file, "\n" }
         }
         exit 0;
     } else {
         unless (@ARGV == 1) {
             die "Usage: $script <path>\n";
         }
-        exit(&{"File::MoreUtil::$func"}($ARGV[0]) ? 0:1);
+        exit(&{"File::Util::Test::$func"}($ARGV[0]) ? 0:1);
     }
 }
 
@@ -53,7 +53,7 @@ App::FileTestUtils - More CLIs for file testing
 
 =head1 VERSION
 
-This document describes version 0.004 of App::FileTestUtils (from Perl distribution App-FileTestUtils), released on 2023-11-02.
+This document describes version 0.005 of App::FileTestUtils (from Perl distribution App-FileTestUtils), released on 2023-11-30.
 
 =head1 DESCRIPTION
 
@@ -106,7 +106,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-FileTestUtils>.
 
 The file testing operators in L<perlfunc>, e.g. C<-s>, C<-x>, C<-r>, etc.
 
-L<File::MoreUtil>
+L<File::Util::Test>
 
 =head1 AUTHOR
 
